@@ -37,9 +37,10 @@ class LLMConfig(BaseModel):
     top_k: int | None = None
     logprobs: bool | None = None
     top_logprobs: int | None = None
-    reasoning_effort: None | Literal["low", "medium", "high"] = (
+    reasoning_effort: None | Literal["minimal", "low", "medium", "high"] = (
         None  # reasoning effort for o-series models. Mutually exclusive with temperature.
     )
+    verbosity: None | Literal["low", "medium", "high"] = None  # verbosity for GPT-5 and newer models
 
     # Custom API configuration for generic API providers
     custom_api_config: dict | None = None
